@@ -1,6 +1,7 @@
 from datetime import date, datetime
 from typing import Any
 from .base import BaseAPI
+from .utils import APIUtils
 from .. import types
 
 class SchoolMosregRUAPI(BaseAPI):
@@ -8,6 +9,7 @@ class SchoolMosregRUAPI(BaseAPI):
     
     def __init__(self, login: str = None, password: str = None, token: str = None, get_info: bool = False) -> None:
         super().__init__(login, password, token)
+        self.utils = APIUtils(self)
 
         if get_info:
             try:
