@@ -2,6 +2,7 @@ import asyncio
 from datetime import date, datetime
 from typing import Any
 from .base import AsyncBaseAPI
+from .utils import AsyncAPIUtils
 from .. import types
 
 class AsyncSchoolMosregRUAPI(AsyncBaseAPI):
@@ -9,6 +10,7 @@ class AsyncSchoolMosregRUAPI(AsyncBaseAPI):
     
     def __init__(self, login: str = None, password: str = None, token: str = None, get_info: bool = False) -> None:
         super().__init__(login, password, token)
+        self.utils = AsyncAPIUtils(self)
 
         if get_info:
             try:
