@@ -1,7 +1,7 @@
 from datetime import datetime
-from pydantic import BaseModel
+from .model import Type
 
-class LessonLogEntries(BaseModel):
+class LessonLogEntries(Type):
     """Отметка о посещаемости (Данный класс - 1 отметка)\n~~~"""
     
     person: int = None
