@@ -1,7 +1,6 @@
-from pydantic import BaseModel
+from .model import Type
 
-
-class Person(BaseModel):
+class Person(Type):
     """Персона."""
     
     id: int
@@ -12,4 +11,4 @@ class Person(BaseModel):
     lastName: str
     middleName: str
     shortName: str
-    sex: str
\ No newline at end of file
+    sex: str
