@@ -1,6 +1,6 @@
-from pydantic import BaseModel
+from .model import Type
 
-class Subject(BaseModel):
+class Subject(Type):
     """[GET] /v2.0/edu-groups/{eduGroup}/subjects\n~~~\n/v2.0/schools/{school}/subjects\n~~~\nСписок предметов, преподаваемых в классе в текущем отчётном периоде или преподаваемых в образовательной организации в текущем учебном году\n~~~\nПрава доступа: EducationalInfo\n~~~"""
     
     id: int
